@@ -74,29 +74,53 @@ class Parameter(ABC):
     extra = {self.extra}
 )"""
 
+    def _call_relational_method(self, method_to_call, other):
+        func = getattr(self.value, method_to_call)
+        return func(_normalize_parameter_value(other))
+
     def __int__(self) -> int:
         """Return integer representation of parameter value."""
         return self.value
 
+    def __add__(self, other) -> int:
+        """Return result of addition."""
+        return self._call_relational_method("__add__", other)
+
+    def __sub__(self, other) -> int:
+        """Return result of the subtraction."""
+        return self._call_relational_method("__sub__", other)
+
+    def __truediv__(self, other):
+        """Return result of true division."""
+        return self._call_relational_method("__truediv__", other)
+
+    def __floordiv__(self, other):
+        """Return result of floored division."""
+        return self._call_relational_method("__floordiv__", other)
+
+    def __mul__(self, other):
+        """Return result of the multiplication."""
+        return self._call_relational_method("__mul__", other)
+
     def __eq__(self, other) -> bool:
         """Compare if parameter value is equal to other."""
-        return self.value == _normalize_parameter_value(other)
+        return self._call_relational_method("__eq__", other)
 
     def __ge__(self, other) -> bool:
         """Compare if parameter value is greater or equal to other."""
-        return self.value >= _normalize_parameter_value(other)
+        return self._call_relational_method("__ge__", other)
 
     def __gt__(self, other) -> bool:
         """Compare if parameter value is greater than other."""
-        return self.value > _normalize_parameter_value(other)
+        return self._call_relational_method("__gt__", other)
 
     def __le__(self, other) -> bool:
         """Compare if parameter value is less or equal to other."""
-        return self.value <= _normalize_parameter_value(other)
+        return self._call_relational_method("__le__", other)
 
     def __lt__(self, other) -> bool:
         """Compare if parameter value is less that other."""
-        return self.value < _normalize_parameter_value(other)
+        return self._call_relational_method("__lt__", other)
 
     def set(self, value: ParameterValueType) -> None:
         """Set parameter value."""
@@ -110,7 +134,7 @@ class Parameter(ABC):
             self._changed = True
         else:
             raise ValueError(
-                f"parameter value must be between {self.min_value} and {self.max_value}"
+                f"Parameter value must be between {self.min_value} and {self.max_value}"
             )
 
     @property
